@@ -87,7 +87,9 @@ class RepairSegmentation(Processor):
                 report.errors = []
                 for error in errors:
                     if isinstance(error, (CoordinateConsistencyError,CoordinateValidityError)):
-                        if error.tag.endswith('Region'):
+                        if error.tag == 'Page':
+                            element = page.get_Border()
+                        elif error.tag.endswith('Region'):
                             element = next((region
                                             for region in page.get_AllRegions()
                                             if region.id == error.ID), None)
@@ -128,7 +130,8 @@ class RepairSegmentation(Processor):
                                 continue
                         else:
                             ensure_valid(element)
-                        LOG.warning("Fixed %s for segment '%s'", error.__class__.__name__, element.id)
+                        LOG.warning("Fixed %s for %s '%s'", error.__class__.__name__,
+                                    error.tag, error.ID)
             if not report.is_valid:
                 LOG.warning(report.to_xml())
 
@@ -304,7 +307,7 @@ class RepairSegmentation(Processor):
                 region_polygon = coordinates_for_segment(polygon, page_image, page_coords)
             if region_polygon is not None:
                 LOG.info('Using new coordinates for region "%s"', region.id)
-                region.get_Coords().points = points_from_polygon(region_polygon)
+                region.get_Coords().set_points(points_from_polygon(region_polygon))
     
 def _plausibilize_group(regionspolys, rogroup, mark_for_deletion, mark_for_merging):
     LOG = getLogger('processor.RepairSegmentation')
@@ -355,7 +358,7 @@ def _plausibilize_group(regionspolys, rogroup, mark_for_deletion, mark_for_mergi
                     superpoly = asPolygon(np.round(superpoly.exterior.coords))
                 superpoly = make_valid(superpoly)
                 superpoly = superpoly.exterior.coords[:-1] # keep open
-                superreg.get_Coords().points = points_from_polygon(superpoly)
+                superreg.get_Coords().set_points(points_from_polygon(superpoly))
                 # FIXME should we merge/mix attributes and features?
                 if region.get_orientation() != superreg.get_orientation():
                     LOG.warning('Merging region "{}" with orientation {} into "{}" with {}'.format(
@@ -416,13 +419,13 @@ def ensure_consistent(child):
                                [parent.get_imageWidth(), 0]])
     else:
         parentp = Polygon(polygon_from_points(parent.get_Coords().points))
-    # check if clipping is necessary
-    if childp.within(parentp):
-        return
     # ensure input coords have valid paths (without self-intersection)
     # (this can happen when shapes valid in floating point are rounded)
     childp = make_valid(childp)
     parentp = make_valid(parentp)
+    # check if clipping is necessary
+    if childp.within(parentp):
+        return
     # clip to parent
     interp = childp.intersection(parentp)
     if interp.is_empty or interp.area == 0.0:
@@ -451,13 +454,25 @@ def ensure_consistent(child):
     child.get_Coords().set_points(points)
 
 def ensure_valid(element):
+    changed = False
     coords = element.get_Coords()
     points = coords.points
     polygon = polygon_from_points(points)
+    array = np.array(polygon, np.int)
+    if array.min() < 0:
+        array = np.maximum(0, array)
+        changed = True
+    if array.shape[0] < 3:
+        array = np.concatenate([
+            array, array[::-1] + 1])
+        changed = True
+    polygon = array.tolist()
     poly = Polygon(polygon)
     if not poly.is_valid:
         poly = make_valid(poly)
         polygon = poly.exterior.coords[:-1]
+        changed = True
+    if changed:
         points = points_from_polygon(polygon)
         coords.set_points(points)
 
